package com.school.project.service.userRegistration.student;

import com.school.project.dto.userRegistration.StudentRegistrationDTO;
import com.school.project.dto.userRegistration.UserDTO;
import com.school.project.model.userRegistration.Role;
import com.school.project.model.userRegistration.Student;
import com.school.project.model.userRegistration.User;
import com.school.project.repository.userRegistration.RoleRepository;
import com.school.project.repository.userRegistration.StudentRegRepository;
import com.school.project.repository.userRegistration.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

import javax.transaction.Transactional;
import java.util.UUID;

@Service
public class StudentRegistrationServiceImpl implements StudentRegistrationService {

    @Autowired
    private StudentRegRepository studentRegRepository;

    @Autowired
    private UserRepository userRepository;

    @Autowired
    private RoleRepository roleRepository;

    @Autowired
    private PasswordEncoder passwordEncoder;

    @Override
    @Transactional
    public UserDTO registerStudent(StudentRegistrationDTO studentRegistrationDTO) {

        //Creating New User
        User newUser = new User();

        newUser.setEmail(studentRegistrationDTO.getEmail());
        newUser.setRole(roleRepository.findByRole(Role.ROLES.STUDENT.name()));
        newUser.setPassword(passwordEncoder.encode(studentRegistrationDTO.getPassword()));

        newUser = userRepository.save(newUser);

        //Creating New Student
        Student newStudent = new Student();

        newStudent.setName(studentRegistrationDTO.getName());
        newStudent.setAge(studentRegistrationDTO.getAge());
        newStudent.setStudentAppUser(newUser);
        newStudent.setRollNumber(studentRegistrationDTO.getRollNumber());

        studentRegRepository.save(newStudent);

        return new UserDTO(newUser.getUserId(), newUser.getEmail());

    }
}
